From d23a8d5758046fc887d16b030e3a48964517e1b1 Mon Sep 17 00:00:00 2001
From: Yudai Nakata <yudai.nkt@gmail.com>
Date: Mon, 11 Sep 2023 14:39:53 +0900
Subject: [PATCH 1/4] Detect browsers in a Deno-compatible way (#821)

---
 src/utils/getEnvironment.js | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/utils/getEnvironment.js b/src/utils/getEnvironment.js
index da7d3eaa..0971d99c 100644
--- a/src/utils/getEnvironment.js
+++ b/src/utils/getEnvironment.js
@@ -7,7 +7,7 @@ module.exports = (key) => {
     env.type = 'webworker';
   } else if (isElectron()) {
     env.type = 'electron';
-  } else if (typeof window === 'object') {
+  } else if (typeof document === 'object') {
     env.type = 'browser';
   } else if (typeof process === 'object' && typeof require === 'function') {
     env.type = 'node';

From ff173ce2043755ea9efd302caa856f360e12e7ee Mon Sep 17 00:00:00 2001
From: Balearica <admin@scribeocr.com>
Date: Wed, 13 Sep 2023 17:53:58 -0700
Subject: [PATCH 2/4] Update api.md

---
 docs/api.md | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/docs/api.md b/docs/api.md
index 2129a4c8..f5b64a18 100644
--- a/docs/api.md
+++ b/docs/api.md
@@ -32,7 +32,8 @@ createWorker is a factory function that creates a tesseract worker, a worker is
 **Arguments:**
 
 - `options` an object of customized options
-  - `corePath` path for tesseract-core.js script
+  - `corePath` path to a directory containing **both** `tesseract-core.wasm.js` and `tesseract-core-simd.wasm.js` from [Tesseract.js-core](https://www.npmjs.com/package/tesseract.js-core) package
+     - Setting `corePath` to a specific `.js` file is **strongly discouraged.**  To provide the best performance on all devices, Tesseract.js needs to be able to pick between `tesseract-core.wasm.js` and `tesseract-core-simd.wasm.js`.  See [this issue](https://github.com/naptha/tesseract.js/issues/735) for more detail.
   - `langPath` path for downloading traineddata, do not include `/` at the end of the path
   - `workerPath` path for downloading worker script
   - `dataPath` path for saving traineddata in WebAssembly file system, not common to modify

From 2a27a0e13e9e66e6f86b19bc3e159e3cc32dad24 Mon Sep 17 00:00:00 2001
From: Frazer Smith <frazer.dev@outlook.com>
Date: Mon, 25 Sep 2023 15:49:45 +0100
Subject: [PATCH 3/4] perf: use `node:` prefix to bypass require.cache call for
 builtins (#824)

---
 benchmarks/node/speed-benchmark.js | 2 +-
 examples/node/detect.js            | 2 +-
 examples/node/download-pdf.js      | 4 ++--
 examples/node/image-processing.js  | 4 ++--
 examples/node/recognize.js         | 2 +-
 scripts/server.js                  | 2 +-
 scripts/test-helper.js             | 4 ++--
 scripts/webpack.config.dev.js      | 2 +-
 scripts/webpack.config.prod.js     | 2 +-
 src/worker-script/node/cache.js    | 4 ++--
 src/worker-script/node/gunzip.js   | 2 +-
 src/worker-script/node/index.js    | 2 +-
 src/worker/node/defaultOptions.js  | 2 +-
 src/worker/node/loadImage.js       | 4 ++--
 src/worker/node/spawnWorker.js     | 2 +-
 15 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/benchmarks/node/speed-benchmark.js b/benchmarks/node/speed-benchmark.js
index 28d3fe72..68ebd29c 100644
--- a/benchmarks/node/speed-benchmark.js
+++ b/benchmarks/node/speed-benchmark.js
@@ -1,5 +1,5 @@
 #!/usr/bin/env node
-const path = require('path');
+const path = require('node:path');
 const { createWorker } = require('../../');
 
 (async () => {
diff --git a/examples/node/detect.js b/examples/node/detect.js
index a3e112a1..8f11608e 100755
--- a/examples/node/detect.js
+++ b/examples/node/detect.js
@@ -1,5 +1,5 @@
 #!/usr/bin/env node
-const path = require('path');
+const path = require('node:path');
 const Tesseract = require('../../');
 
 const [,, imagePath] = process.argv;
diff --git a/examples/node/download-pdf.js b/examples/node/download-pdf.js
index 3c459973..f12d8174 100755
--- a/examples/node/download-pdf.js
+++ b/examples/node/download-pdf.js
@@ -1,6 +1,6 @@
 #!/usr/bin/env node
-const path = require('path');
-const fs = require('fs');
+const path = require('node:path');
+const fs = require('node:fs');
 const { createWorker } = require('../../');
 
 const [,, imagePath] = process.argv;
diff --git a/examples/node/image-processing.js b/examples/node/image-processing.js
index e4297a9f..9de7d9ab 100755
--- a/examples/node/image-processing.js
+++ b/examples/node/image-processing.js
@@ -1,6 +1,6 @@
 #!/usr/bin/env node
-const path = require('path');
-const fs = require('fs');
+const path = require('node:path');
+const fs = require('node:fs');
 const { createWorker } = require('../../');
 
 const [,, imagePath] = process.argv;
diff --git a/examples/node/recognize.js b/examples/node/recognize.js
index 082ffa0c..a01b333e 100755
--- a/examples/node/recognize.js
+++ b/examples/node/recognize.js
@@ -1,5 +1,5 @@
 #!/usr/bin/env node
-const path = require('path');
+const path = require('node:path');
 const { createWorker } = require('../../');
 
 const [,, imagePath] = process.argv;
diff --git a/scripts/server.js b/scripts/server.js
index 8e857f5f..a53052a0 100644
--- a/scripts/server.js
+++ b/scripts/server.js
@@ -1,7 +1,7 @@
 const webpack = require('webpack');
 const middleware = require('webpack-dev-middleware');
 const express = require('express');
-const path = require('path');
+const path = require('node:path');
 const cors = require('cors');
 const webpackConfig = require('./webpack.config.dev');
 
diff --git a/scripts/test-helper.js b/scripts/test-helper.js
index 027b3006..3a2b3975 100644
--- a/scripts/test-helper.js
+++ b/scripts/test-helper.js
@@ -1,7 +1,7 @@
 const constants = require('../tests/constants');
 global.expect = require('expect.js');
-global.fs = require('fs');
-global.path = require('path');
+global.fs = require('node:fs');
+global.path = require('node:path');
 global.Tesseract = require('../src');
 
 Object.keys(constants).forEach((key) => {
diff --git a/scripts/webpack.config.dev.js b/scripts/webpack.config.dev.js
index e807f43d..d218c55a 100644
--- a/scripts/webpack.config.dev.js
+++ b/scripts/webpack.config.dev.js
@@ -1,4 +1,4 @@
-const path = require('path');
+const path = require('node:path');
 const webpack = require('webpack');
 const { BundleAnalyzerPlugin } = require('webpack-bundle-analyzer');
 const common = require('./webpack.config.common');
diff --git a/scripts/webpack.config.prod.js b/scripts/webpack.config.prod.js
index e581df7a..b92d5e3a 100644
--- a/scripts/webpack.config.prod.js
+++ b/scripts/webpack.config.prod.js
@@ -1,4 +1,4 @@
-const path = require('path');
+const path = require('node:path');
 const common = require('./webpack.config.common');
 const webpack = require('webpack');
 
diff --git a/src/worker-script/node/cache.js b/src/worker-script/node/cache.js
index e04809e2..fd6bab6b 100644
--- a/src/worker-script/node/cache.js
+++ b/src/worker-script/node/cache.js
@@ -1,5 +1,5 @@
-const util = require('util');
-const fs = require('fs');
+const util = require('node:util');
+const fs = require('node:fs');
 
 module.exports = {
   readCache: util.promisify(fs.readFile),
diff --git a/src/worker-script/node/gunzip.js b/src/worker-script/node/gunzip.js
index 4f2e0e0c..40f32949 100644
--- a/src/worker-script/node/gunzip.js
+++ b/src/worker-script/node/gunzip.js
@@ -1 +1 @@
-module.exports = require('zlib').gunzipSync;
+module.exports = require('node:zlib').gunzipSync;
diff --git a/src/worker-script/node/index.js b/src/worker-script/node/index.js
index c00dba73..fb187b05 100644
--- a/src/worker-script/node/index.js
+++ b/src/worker-script/node/index.js
@@ -9,7 +9,7 @@
  */
 
 const fetch = require('node-fetch');
-const { parentPort } = require('worker_threads');
+const { parentPort } = require('node:worker_threads');
 const worker = require('..');
 const getCore = require('./getCore');
 const gunzip = require('./gunzip');
diff --git a/src/worker/node/defaultOptions.js b/src/worker/node/defaultOptions.js
index 053c1e3e..498714c4 100644
--- a/src/worker/node/defaultOptions.js
+++ b/src/worker/node/defaultOptions.js
@@ -1,4 +1,4 @@
-const path = require('path');
+const path = require('node:path');
 const defaultOptions = require('../../constants/defaultOptions');
 
 /*
diff --git a/src/worker/node/loadImage.js b/src/worker/node/loadImage.js
index 0b5a660f..07d684e8 100644
--- a/src/worker/node/loadImage.js
+++ b/src/worker/node/loadImage.js
@@ -1,5 +1,5 @@
-const util = require('util');
-const fs = require('fs');
+const util = require('node:util');
+const fs = require('node:fs');
 const fetch = require('node-fetch');
 const isURL = require('is-url');
 
diff --git a/src/worker/node/spawnWorker.js b/src/worker/node/spawnWorker.js
index 9723c183..c26537d1 100644
--- a/src/worker/node/spawnWorker.js
+++ b/src/worker/node/spawnWorker.js
@@ -1,4 +1,4 @@
-const { Worker } = require('worker_threads');
+const { Worker } = require('node:worker_threads');
 
 /**
  * spawnWorker

From ccf7414bc22b1f3710fb2998183ca9966254cc7a Mon Sep 17 00:00:00 2001
From: Balearica <admin@scribeocr.com>
Date: Wed, 27 Sep 2023 19:01:15 -0700
Subject: [PATCH 4/4] 4.1.3

---
 package-lock.json | 4 ++--
 package.json      | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/package-lock.json b/package-lock.json
index 0b7507e1..4238da2f 100644
--- a/package-lock.json
+++ b/package-lock.json
@@ -1,12 +1,12 @@
 {
   "name": "tesseract.js",
-  "version": "4.1.2",
+  "version": "4.1.3",
   "lockfileVersion": 2,
   "requires": true,
   "packages": {
     "": {
       "name": "tesseract.js",
-      "version": "4.1.2",
+      "version": "4.1.3",
       "hasInstallScript": true,
       "license": "Apache-2.0",
       "dependencies": {
diff --git a/package.json b/package.json
index c6358d04..7d44a2c0 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
 {
   "name": "tesseract.js",
-  "version": "4.1.2",
+  "version": "4.1.3",
   "description": "Pure Javascript Multilingual OCR",
   "main": "src/index.js",
   "types": "src/index.d.ts",
